@@ -87,6 +87,12 @@ type BootAssetRawFiles struct {
 	Offset string `yaml:"offset"`
 }
 
+type BootAssetRawPartitions struct {
+	Name string `yaml:"name"`
+	Size string `yaml:"size"`
+	Type string `yaml:"type"`
+}
+
 type BootAssetFiles struct {
 	Path string `yaml:"path"`
 	// Target is the deprecated target relative to $bootloader dir
@@ -96,8 +102,9 @@ type BootAssetFiles struct {
 }
 
 type BootAssets struct {
-	Files    []BootAssetFiles    `yaml:"files,omitempty"`
-	RawFiles []BootAssetRawFiles `yaml:"raw-files,omitempty"`
+	Files         []BootAssetFiles         `yaml:"files,omitempty"`
+	RawFiles      []BootAssetRawFiles      `yaml:"raw-files,omitempty"`
+	RawPartitions []BootAssetRawPartitions `yaml:"raw-partitions,omitempty"`
 }
 
 type OemDescription struct {
@@ -201,6 +208,7 @@ type BaseImage struct {
 	partCount int
 	size      int64
 	rootSize  int
+	label     string
 }
 
 // Mount mounts the image. This also maps the loop device.
@@ -501,6 +509,11 @@ func (img *BaseImage) FlashExtra() error {
 	}
 
 	if bootAssets := img.oem.OEM.Hardware.BootAssets; bootAssets != nil {
+		if bootAssets.RawPartitions != nil {
+			if err := setupBootAssetRawPartitions(img.location, img.partCount, bootAssets.RawPartitions); err != nil {
+				return err
+			}
+		}
 		return setupBootAssetRawFiles(img.location, oemRoot, bootAssets.RawFiles)
 	}
 
