@@ -17,8 +17,6 @@ import (
 	"path/filepath"
 	"strings"
 	"time"
-
-	"github.com/ubuntu-core/snappy/helpers"
 )
 
 // This program is free software: you can redistribute it and/or modify it
@@ -103,10 +101,12 @@ func (coreCmd *CoreCmd) setupOemConfigs() error {
 	}
 
 	// first we need to copy all the files in modprobe.d
-	systemModprobeDir := filepath.Join(coreCmd.img.System(), "etc", "modprobe.d")
-	if err := helpers.RSyncWithDelete(systemModprobeDir, modprobeDir); err != nil {
-		return err
-	}
+	/*
+		systemModprobeDir := filepath.Join(coreCmd.img.System(), "etc", "modprobe.d")
+			if err := helpers.RSyncWithDelete(systemModprobeDir, modprobeDir); err != nil {
+				return err
+			}
+	*/
 
 	modprobeD := filepath.Join(modprobeDir, "ubuntu-core.conf")
 	modprobeDFile, err := os.Create(modprobeD)
