@@ -20,15 +20,18 @@ package main
 // with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 import (
+	"bufio"
 	"errors"
 	"fmt"
 	"os"
+	"os/exec"
 	"path/filepath"
 	"runtime"
 	"syscall"
+	"text/template"
 
-	"launchpad.net/goget-ubuntu-touch/ubuntu-emulator/diskimage"
-	"launchpad.net/goget-ubuntu-touch/ubuntu-emulator/sysutils"
+	"launchpad.net/goget-ubuntu-touch/diskimage"
+	"launchpad.net/goget-ubuntu-touch/sysutils"
 	"launchpad.net/goget-ubuntu-touch/ubuntuimage"
 )
 
@@ -39,6 +42,8 @@ type CreateCmd struct {
 	RawDisk  bool   `long:"use-raw-disk" description:"Use raw disks instead of qcow2"`
 	SDCard   bool   `long:"with-sdcard" description:"Create an external vfat sdcard"`
 	Arch     string `long:"arch" description:"Device architecture to use (i386 or armhf)"`
+	Password string `long:"password" description:"This sets up the default password for the phablet user" default:"0000"`
+	Locale   string `long:"locale" description:"Use a different locale than the default one (e.g.; --locale es_AR.utf8)"`
 }
 
 var createCmd CreateCmd
@@ -49,6 +54,41 @@ const (
 	defaultArch    = "i386"
 )
 
+const (
+	binQemuArmStatic  = "/usr/bin/qemu-arm-static"
+	pkgQemuUserStatic = "qemu-user-static"
+)
+
+const localeTemplate string = `description "Set wizard language"
+author "ubuntu-emulator"
+
+start on starting ubuntu-system-settings-wizard
+
+task
+
+script
+    setenv() {
+        initctl set-env --global $1=$2
+        gdbus call --session --dest org.freedesktop.DBus --object-path /org/freedesktop/DBus --method org.freedesktop.DBus.UpdateActivationEnvironment "@a{ss} {'$1': '$2'}"
+    }
+
+    uid=$(getent passwd $USER|cut -d: -f3)
+    if [ -z $uid ];then
+        exit 1
+    fi
+    if [ ! -e $HOME/.cache/.first-lang-set ]; then
+    setenv LANGUAGE {{ . }}
+    setenv LC_ALL {{ . }}
+    setenv LANG {{ . }}
+    dbus-send --print-reply --system --dest=org.freedesktop.Accounts /org/freedesktop/Accounts/User$uid org.freedesktop.Accounts.User.SetFormatsLocale string:{{ . }}
+    dbus-send --print-reply --system --dest=org.freedesktop.Accounts /org/freedesktop/Accounts/User$uid org.freedesktop.Accounts.User.SetLanguage string:{{ . }}
+    touch $HOME/.cache/.first-lang-set
+    fi
+end script
+
+# vim:syntax=upstart
+`
+
 func init() {
 	createCmd.Arch = defaultArch
 	createCmd.Channel = defaultChannel
@@ -66,6 +106,10 @@ func (createCmd *CreateCmd) Execute(args []string) error {
 	}
 	instanceName := args[0]
 
+	if err := createCmd.verifyDependencies(); err != nil {
+		return err
+	}
+
 	var device string
 	if d, ok := devices[createCmd.Arch]; ok {
 		device = d["name"]
@@ -118,7 +162,7 @@ func (createCmd *CreateCmd) Execute(args []string) error {
 	sdcardImage := diskimage.New(filepath.Join(dataDir, "sdcard.img"), "USERDATA", 4)
 	systemImage := diskimage.NewExisting(filepath.Join(dataDir, "system.img"))
 
-	if err := createSystem(ubuntuImage, sdcardImage, files); err != nil {
+	if err := createCmd.createSystem(ubuntuImage, sdcardImage, files); err != nil {
 		return err
 	}
 
@@ -161,10 +205,10 @@ func (createCmd *CreateCmd) Execute(args []string) error {
 		}
 	}
 
-	if err = sysutils.WriteStamp(dataDir, image); err != nil {
+	if err = writeStamp(dataDir, image); err != nil {
 		return err
 	}
-	if err = sysutils.WriteDeviceStamp(dataDir, createCmd.Arch); err != nil {
+	if err = writeDeviceStamp(dataDir, createCmd.Arch); err != nil {
 		return err
 	}
 
@@ -179,7 +223,18 @@ func extractBuildProperties(systemImage *diskimage.DiskImage, dataDir string) er
 	return systemImage.ExtractFile("build.prop", filepath.Join(dataDir, "system"))
 }
 
-func createSystem(ubuntuImage, sdcardImage *diskimage.DiskImage, files []string) (err error) {
+func (createCmd *CreateCmd) verifyDependencies() error {
+	switch createCmd.Arch {
+	case "armhf":
+		if _, err := os.Stat(binQemuArmStatic); err != nil {
+			return fmt.Errorf("missing dependency %s (apt install %s)", binQemuArmStatic, pkgQemuUserStatic)
+		}
+	}
+
+	return nil
+}
+
+func (createCmd *CreateCmd) createSystem(ubuntuImage, sdcardImage *diskimage.DiskImage, files []string) (err error) {
 	for _, img := range []*diskimage.DiskImage{ubuntuImage, sdcardImage} {
 		if err := img.CreateExt4(); err != nil {
 			return err
@@ -205,13 +260,22 @@ func createSystem(ubuntuImage, sdcardImage *diskimage.DiskImage, files []string)
 		}
 		return err
 	}
-	fmt.Println("Setting up a default password for phablet to: '0000'")
-	if err := ubuntuImage.SetPassword("phablet", "0000"); err != nil {
+
+	fmt.Printf("Setting up a default password for phablet to: '%s'\n", createCmd.Password)
+	if err := createCmd.setPassword(ubuntuImage.Mountpoint); err != nil {
 		if err := ubuntuImage.Unmount(); err != nil {
 			fmt.Println("Unmount error :", err)
 		}
 		return err
 	}
+
+	if err := createCmd.setLocale(ubuntuImage.Mountpoint); err != nil {
+		if err := ubuntuImage.Unmount(); err != nil {
+			fmt.Println("Unmount error :", err)
+		}
+		return err
+	}
+
 	if err := ubuntuImage.Unmount(); err != nil {
 		return err
 	}
@@ -222,12 +286,110 @@ func createSystem(ubuntuImage, sdcardImage *diskimage.DiskImage, files []string)
 	if err = sdcardImage.Writable(); err != nil {
 		return err
 	}
+	if err = sdcardImage.OverrideAdbInhibit(); err != nil {
+		return err
+	}
 	if err := ubuntuImage.Move(filepath.Join(sdcardImage.Mountpoint, "system.img")); err != nil {
 		return err
 	}
 	return nil
 }
 
+// setLocale sets the locale to the one specified in locale
+func (createCmd *CreateCmd) setLocale(chroot string) error {
+	if createCmd.Locale == "" {
+		return nil
+	}
+
+	if createCmd.Arch == "armhf" {
+		if err := addQemuStatic(chroot); err != nil {
+			return err
+		}
+
+		defer removeQemuStatic(chroot)
+	}
+
+	cmd := exec.Command("chroot", chroot, "/bin/sh", "-c", "locale -a")
+	stdout, err := cmd.StdoutPipe()
+	if err != nil {
+		return err
+	}
+
+	if err := cmd.Start(); err != nil {
+		return err
+	}
+
+	// Verify that the locale is actually part of the emulator
+	var localeInstalled bool
+
+	scanner := bufio.NewScanner(stdout)
+	for scanner.Scan() {
+		locale := scanner.Text()
+		if createCmd.Locale == locale {
+			localeInstalled = true
+			break
+		}
+	}
+
+	if !localeInstalled {
+		return errors.New("the selected locale is not available on the image")
+	}
+
+	if err := scanner.Err(); err != nil {
+		return err
+	}
+
+	if err := cmd.Wait(); err != nil {
+		return err
+	}
+
+	// Setup the locale
+	localeFile, err := os.Create(filepath.Join(chroot, "/usr/share/upstart/sessions/emulator-language.conf"))
+	if err != nil {
+		return err
+	}
+	defer localeFile.Close()
+
+	t := template.Must(template.New("locale").Parse(localeTemplate))
+
+	return t.Execute(localeFile, createCmd.Locale)
+}
+
+// setPassword is an ugly hack to set the password
+func (createCmd *CreateCmd) setPassword(chroot string) error {
+	if createCmd.Arch == "armhf" {
+		if err := addQemuStatic(chroot); err != nil {
+			return err
+		}
+
+		defer removeQemuStatic(chroot)
+	}
+
+	// Run something that would look like this
+	// PATH=$path chroot "$SYSTEM_MOUNTPOINT" /bin/sh -c "echo -n "$user:$password" | chpasswd"
+	chrootCmd := fmt.Sprintf("echo -n '%s:%s' | chpasswd", "phablet", createCmd.Password)
+	if out, err := exec.Command("chroot", chroot, "/bin/sh", "-c", chrootCmd).CombinedOutput(); err != nil {
+		return errors.New(string(out))
+	}
+
+	return nil
+}
+
+func addQemuStatic(chroot string) error {
+	dst := filepath.Join(chroot, binQemuArmStatic)
+	if out, err := exec.Command("cp", binQemuArmStatic, dst).CombinedOutput(); err != nil {
+		return fmt.Errorf("issues while setting up password: %s", out)
+	}
+
+	return nil
+}
+
+func removeQemuStatic(chroot string) error {
+	dst := filepath.Join(chroot, binQemuArmStatic)
+
+	return os.Remove(dst)
+}
+
 func download(image ubuntuimage.Image) (files []string, err error) {
 	cacheDir := ubuntuimage.GetCacheDir()
 	totalFiles := len(image.Files)
